/*
 * Syncdaemon API
 *
 * Authors: Rodrigo Moya <rodrigo.moya@canonical.com>
 *
 * Copyright 2010 Canonical Ltd.
 *
 * This program is free software: you can redistribute it and/or modify it
 * under the terms of the GNU General Public License version 3, as published
 * by the Free Software Foundation.
 *
 * This program is distributed in the hope that it will be useful, but
 * WITHOUT ANY WARRANTY; without even the implied warranties of
 * MERCHANTABILITY, SATISFACTORY QUALITY, or FITNESS FOR A PARTICULAR
 * PURPOSE.  See the GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License along
 * with this program.  If not, see <http://www.gnu.org/licenses/>.
 *
 */

#include "syncdaemon-daemon.h"
#include "syncdaemon-config-interface.h"

static SyncdaemonDaemon *the_daemon = NULL;

static void
test_daemon (void)
{
	syncdaemon_daemon_connect (the_daemon);
}

static void
test_config (void)
{
	SyncdaemonConfigInterface *config;

	config = (SyncdaemonConfigInterface *) syncdaemon_daemon_get_config_interface (the_daemon);
	g_assert (SYNCDAEMON_IS_CONFIG_INTERFACE (config));
}

static void
daemon_connected_cb (SyncdaemonDaemon *daemon, gpointer user_data)
{
	g_debug ("Daemon is now connected, and root_dir = ", syncdaemon_daemon_get_root_dir (the_daemon));
	syncdaemon_daemon_disconnect (the_daemon);
}

static void
daemon_disconnected_cb (SyncdaemonDaemon *daemon, gpointer user_data)
{
	g_debug ("Daemon is now disconnected");
	syncdaemon_daemon_connect (the_daemon);
}

int
main (int argc, gchar *argv[])
{
	g_type_init ();
	g_test_init (&argc, &argv, NULL);

	/* Initialize main object */
	the_daemon = syncdaemon_daemon_new ();
	g_signal_connect (G_OBJECT (the_daemon), "connected", G_CALLBACK (daemon_connected_cb), NULL);
	g_signal_connect (G_OBJECT (the_daemon), "disconnected", G_CALLBACK (daemon_disconnected_cb), NULL);

	/* Add test functions */
	g_test_add_func ("/testlibsyncdaemon/TestDaemon", test_daemon);
	g_test_add_func ("/testlibsyncdaemon/TestConfig", test_config);

	return g_test_run ();
}
